@@ -3,6 +3,7 @@ from emmet.core.polar import DielectricDoc
 
 from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
 from emmet.api.routes.dielectric.query_operators import DielectricQuery
+from emmet.api.routes.materials.query_operators import MultiMaterialIDQuery
 from emmet.api.core.global_header import GlobalHeaderProcessor
 from emmet.api.core.settings import MAPISettings
 
@@ -12,12 +13,11 @@ def dielectric_resource(dielectric_store):
         dielectric_store,
         DielectricDoc,
         query_operators=[
+            MultiMaterialIDQuery(),
             DielectricQuery(),
             SortQuery(),
             PaginationQuery(),
-            SparseFieldsQuery(
-                DielectricDoc, default_fields=["material_id", "last_updated"]
-            ),
+            SparseFieldsQuery(DielectricDoc, default_fields=["material_id", "last_updated"]),
         ],
         header_processor=GlobalHeaderProcessor(),
         tags=["Dielectric"],
